aboutsummaryrefslogtreecommitdiffstats
path: root/Software/PMR
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2020-07-05 14:06:24 +0300
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2020-07-05 14:06:24 +0300
commitcfa09b21e9ea44b2276d261238b6c999bdebc4c3 (patch)
tree4330bb71cc1d364a14fd0580004cb5cb40a23e25 /Software/PMR
parente736f9d6f148f415068cc6923f654e455da2dd14 (diff)
downloadTango-cfa09b21e9ea44b2276d261238b6c999bdebc4c3.tar.gz
Tango-cfa09b21e9ea44b2276d261238b6c999bdebc4c3.zip
Updated event types BL & PMR.
Diffstat (limited to 'Software/PMR')
-rw-r--r--Software/PMR/Messages/Diagnostics/EventType.proto41
1 files changed, 31 insertions, 10 deletions
diff --git a/Software/PMR/Messages/Diagnostics/EventType.proto b/Software/PMR/Messages/Diagnostics/EventType.proto
index b7872cf35..c165e893f 100644
--- a/Software/PMR/Messages/Diagnostics/EventType.proto
+++ b/Software/PMR/Messages/Diagnostics/EventType.proto
@@ -83,7 +83,7 @@ enum EventType
CARTRIDGES_COVER_OPEN = 2006;
//Cover is open. Cannot execute job (Group = GeneralHardware, Category = Error)
- REAR_COVER_OPEN = 2007;
+ ARCH_COVER_OPEN = 2007;
//The machine temperature is too high. Cannot execute job (Group = GeneralHardware, Category = Critical)
MACHINE_INTERNAL_OVERTEMPERATURE = 2008;
@@ -124,6 +124,9 @@ enum EventType
//Software error has occurred (Group = GeneralHardware, Category = Error)
UNINTENDED_RESET = 2020;
+ //Temperature measurement error has occurred. Cannot execute job. (Group = GeneralHardware, Category = Error)
+ TEMPERATURE_MEASUREMENT_ERROR = 2021;
+
//Thread break. Cannot execute job (Group = ThreadFeedingSystem, Category = Error)
THREAD_BREAK = 3000;
@@ -625,6 +628,24 @@ enum EventType
//Dyeing head actuator did not reach position. Cannot execute job (Group = DyeingHead, Category = Error)
DYEING_HEAD_LEFT_ACTUATOR_DOWN_TIMEOUT = 5092;
+ //Dyeing head blower flow is too high. Cannot execute job (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_BLOWER_1_FLOW_TOO_HIGH = 5093;
+
+ //Dyeing head blower flow is too high. Cannot execute job (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_BLOWER_2_FLOW_TOO_HIGH = 5094;
+
+ //Dyeing head blower flow is too low. Cannot execute job (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_BLOWER_1_FLOW_TOO_LOW = 5095;
+
+ //Dyeing head blower flow is too low. Cannot execute job (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_BLOWER_2_FLOW_TOO_LOW = 5096;
+
+ //Dyeing head arc lid is open. Cannot execute job. (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_ARC_LID_IS_OPEN = 5097;
+
+ //Dyeing head tunnel lid is open. Cannot execute job (Group = DyeingHead, Category = Error)
+ DYEING_HEAD_TUNNEL_LID_IS_OPEN = 5098;
+
//The temperature in the mixer is too high. Cannot execute job (Group = Mixer, Category = Critical)
MIXER_OVERTEMPERATURE = 6000;
@@ -667,28 +688,28 @@ enum EventType
//Overpressure in lubricant dispenser. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_8_OVERPRESSURE = 7007;
//The pressure in black dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_1_UNDERPRESSURE = 7008;
//The pressure in cyan dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_2_UNDERPRESSURE = 7009;
//The pressure in magenta dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_3_UNDERPRESSURE = 7010;
//The pressure in yellow dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_4_UNDERPRESSURE = 7011;
//The pressure in transparent ink dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_5_UNDERPRESSURE = 7012;
//The pressure in spot color 1 dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_6_UNDERPRESSURE = 7013;
//The pressure in cleaner dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_7_UNDERPRESSURE = 7014;
//The pressure in lubricant dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_8_UNDERPRESSURE = 7015;
//Black dispenser is empty (Group = Dispensers, Category = Error)
@@ -1024,7 +1045,7 @@ enum EventType
//Chiller malfunction. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)
CHILLER_DRY_CONTACT = 9006;
//Insufficient air flow. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)
INSUFFICIENT_AIR_FLOW = 9007;
//Air quality alert. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)
@@ -667,28 +688,28 @@ enum EventType
//Overpressure in lubricant dispenser. Cannot execute job (Group = Dispensers, Category = Critical)
DISPENSER_8_OVERPRESSURE = 7007;
- //The pressure in black dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in black dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_1_UNDERPRESSURE = 7008;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_1_UNDERPRESSURE = 7008;
- //The pressure in cyan dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in cyan dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_2_UNDERPRESSURE = 7009;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_2_UNDERPRESSURE = 7009;
- //The pressure in magenta dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in magenta dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_3_UNDERPRESSURE = 7010;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_3_UNDERPRESSURE = 7010;
- //The pressure in yellow dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in yellow dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_4_UNDERPRESSURE = 7011;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_4_UNDERPRESSURE = 7011;
- //The pressure in transparent ink dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in transparent ink dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_5_UNDERPRESSURE = 7012;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_5_UNDERPRESSURE = 7012;
- //The pressure in spot color 1 dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in spot color 1 dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_6_UNDERPRESSURE = 7013;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_6_UNDERPRESSURE = 7013;
- //The pressure in cleaner dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in cleaner dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_7_UNDERPRESSURE = 7014;
@@ -667,28 +688,28 @@ enum EventType
DISPENSER_7_UNDERPRESSURE = 7014;
- //The pressure in lubricant dispenser is too low. Cannot execute job (Group = Dispensers, Category = Critical)
+ //The pressure in lubricant dispenser is too low. Cannot execute job (Group = Dispensers, Category = Error)
DISPENSER_8_UNDERPRESSURE = 7015;
//Black dispenser is empty (Group = Dispensers, Category = Error)
@@ -1024,7 +1045,7 @@ enum EventType
//Chiller malfunction. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)
CHILLER_DRY_CONTACT = 9006;
- //Insufficient air flow. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)
+ //Insufficient air flow. Cannot execute job (Group = WasteHandlingSystem, Category = Error)
INSUFFICIENT_AIR_FLOW = 9007;
//Air quality alert. Cannot execute job (Group = WasteHandlingSystem, Category = Critical)